// tgRegistry class for accessing the Windows registry
//
// (c) 2001 by Tom Grandgent, started on 12/6/2001

#include <windows.h>

class tgRegistry
{
private:
	HKEY hive, key;
	char *keyName;
	REGSAM samDesired;
	unsigned long disposition;

public:
	tgRegistry(void);
	tgRegistry(char *newKeyName);
	tgRegistry(HKEY newHive, char *newKeyName);
	~tgRegistry(void);

	void initDefaultValues(void);
	void useHive(HKEY newHive);
	void useKey(char *newKeyName);
	void closeKey(void);

	LONG createKey(void);
	LONG createKey(char *newKeyName);

	LONG openKey(void);
	LONG openKey(char *newKeyName);

	LONG setValue(char *name, DWORD type, void *data, DWORD dataLen);
	LONG setValueInt(char *name, DWORD data);
	LONG setValueString(char *name, char *data);
	LONG setFlag(char *name, int flagTrue);

	LONG getValue(char *name, void *data, DWORD dataLen);
	LONG getValueInt(char *name, int *data);
	LONG getValueInt(char *name, int *data, int defaultValue);
	LONG getValueString(char *name, char *data, DWORD dataLen);
	LONG getValueString(char *name, char *data, DWORD dataLen, char *defaultValue);
	int getFlag(char *name);

	void useSecurity(REGSAM newSamDesired) { samDesired = newSamDesired; }
};

/* Example write:

	tgRegistry reg;

	reg.createKey("Software\\Tom Grandgent");
	reg.createKey("Software\\Tom Grandgent\\tg3d");
	reg.setValueInt("width", width);
	reg.setValueInt("height", height);
	reg.setValueInt("format", format);
	reg.setValueInt("refresh", refresh);
	reg.setValueInt("windowed", windowed);

   Example read:

	tgRegistry reg("Software\\Tom Grandgent\\tg3d");

	reg.getValueInt("width", &width);
	reg.getValueInt("height", &height);
	reg.getValueInt("format", &format);
	reg.getValueInt("refresh", &refresh);
	reg.getValueInt("windowed", &windowed);
*/